@@ -1,20 +1,13 @@
 package Imager::File::SGI;
+use 5.006;
 use strict;
 use Imager;
-use vars qw($VERSION @ISA);
 
 BEGIN {
-  $VERSION = "0.01";
+  our $VERSION = "0.05";
   
-  eval {
-    require XSLoader;
-    XSLoader::load('Imager::File::SGI', $VERSION);
-    1;
-  } or do {
-    require DynaLoader;
-    push @ISA, 'DynaLoader';
-    bootstrap Imager::File::SGI $VERSION;
-  };
+  require XSLoader;
+  XSLoader::load('Imager::File::SGI', $VERSION);
 }
 
 Imager->register_reader
